/******** <lalVerbatim file="BlockFinalizeSearchCV"> ********
Author: Tibbits, M. M.
$Id: BlockFinalizeSearch.c,v 1.2 2002/07/05 20:52:38 tibbits Exp $
********* </lalVerbatim> ********/

/*************************** <lalLaTeX file="BlockFinalizeSearchC">
\subsection{Module \texttt{BlockFinalizeSearch.c}}
\label{s:BlockFinalizeSearch.c}

Routine that cleans up after the stochastic search.

\subsubsection*{Prototypes}
\input{BlockFinalizeSearchCP}
\index{\texttt{LALFinalizeSearch()}}

\subsection*{Description}

Cleans up after the block normal search--i.e., frees memory previously 
allocated in the \texttt{LALConditionData} routine. 

\subsection*{Algorithms}
  
\subsection*{Uses}

\begin{itemize}
\item \texttt{LALDDestroyVectorSequence} 
\item \texttt{LALDDestroyVector} 
\item \texttt{LALFree}
\end{itemize}

\subsection*{Notes}

\vfill{\footnotesize\input{BlockFinalizeSearchCV}}

*************************************************** </lalLaTeX> */

#include "BlockFinalizeSearch.h"

NRCSID( BLOCKFINALIZESEARCHC, "$Id: BlockFinalizeSearch.c,v 1.2 2002/07/05 20:52:38 tibbits Exp $");

/************************ <lalVerbatim file="BlockFinalizeSearchCP"> */
void LALFinalizeSearch
(
	LALStatus		*status,
	void			**searchParams
)
/*********************************************** </lalVerbatim> */
{
	BlockSearchParams	*params;
	UINT4			iterator = 0;

	INITSTATUS( status, "LALFinalizeSearch", BLOCKFINALIZESEARCHC );
	ATTATCHSTATUSPTR (status);

	params = ((BlockSearchParams*)(*searchParams));

	if ( params->data != NULL)
	{
		printf(" Vectors to destroy = %d \n", params->data->numberOfVectors);
		for ( iterator = 0; iterator < params->data->numberOfVectors; iterator++)
		{
			LALDDestroyVector(status->statusPtr, &(params->data->vector[iterator]));
			CHECKSTATUSPTR(status);
		}

		LALFree(params->data->vector);
	        CHECKSTATUSPTR(status);

		LALFree(params->data);
		CHECKSTATUSPTR(status);
	}

        if ( params->dataRho3 != NULL)
        {
		printf(" Vectors to destroy = %d \n", params->dataRho3->numberOfVectors);
                for ( iterator = 0; iterator < params->dataRho3->numberOfVectors; iterator++)
                {
                        LALDDestroyVector(status->statusPtr, &(params->dataRho3->vector[iterator]));
                        CHECKSTATUSPTR(status);
                }

                LALFree(params->dataRho3->vector);
                CHECKSTATUSPTR(status);

                LALFree(params->dataRho3);
                CHECKSTATUSPTR(status);
        }

        if ( params->vec != NULL)
        {        
        	LALDDestroyVector(status->statusPtr, &(params->vec));
		CHECKSTATUSPTR(status);
	}

        if ( params->res != NULL)
        {
		LALDDestroyVector(status->statusPtr, &(params->res)); 
		CHECKSTATUSPTR(status);
	}

        if ( params->value != NULL)
        {
                LALDDestroyVector(status->statusPtr, &(params->value));
                CHECKSTATUSPTR(status);
        }

        if ( params->ndx != NULL)
        {
                LALI4DestroyVector(status->statusPtr, &(params->ndx));
                CHECKSTATUSPTR(status);
        }

        if ( *searchParams != NULL)
        {
		LALFree(params);
		CHECKSTATUSPTR(status);
	}

	DETATCHSTATUSPTR (status);
	RETURN(status);
}
