/******** <lalVerbatim file="MatrixPowerCV"> ********
Author: Tibbits, M. M.
$Id: MatrixPower.m4,v 1.1 2002/07/05 20:53:51 tibbits Exp $
********* </lalVerbatim> ********/

/******************************* <lalLaTeX file="MatrixPowerC">
\section{Module \texttt{MatrixPower.c}}
\label{s:MatrixPower.c}
This file is dedicated to reproducing the matlab function " \verb+.^+ ".  This file
has several declarations of the same function taking all forms of available
input.  This being said, I have yet to script the complex actions and their
counterparts.


\subsection*{Description}

This file is to help make the conversion from Matlab to c much earier.
In this file, we have created all of the versions of \verb+.^+ that we plan on
using.

\subsection*{Algorithms}

The algorithm is the same as it is in matlab.  The dot in front of an operator
in matlab signifies that if either or both of the operands are vectors, then
the operation will be carried out member by member.  For instance

vector a[25];
vector b[25];
vector c[25];

c = a \verb+.^+ b;

The result of this is:

\(c[0] =	a[0] ^{b[0]}\);
\(c[1] =	a[1] ^{b[1]}\);
.	.	.
.	.	.
.	.	.

etc.

\subsection*{Uses}
 
\begin{itemize}
\item \texttt{LALDCreateVector}
\end{itemize}

\subsection*{Notes}

At the current time none of the operations have been specified for neither the
complex datatypes nor the unsigned datatypes.

\subsubsection*{Prototypes}

 *************************************************** </lalLaTeX> */

#include <math.h>
#include "Matrix.h"

NRCSID( MATLABMATRIXPOWC, "$Id: MatrixPower.m4,v 1.1 2002/07/05 20:53:51 tibbits Exp $");
























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerDVector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, REAL8Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerDVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        REAL8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotPowerDVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void DVectorDotPowerD ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, REAL8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerD (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        REAL8			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerD" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DVectorDotPowerDVector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *B, REAL8Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerDVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*B,
        REAL8Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerDVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerDArray ( LALStatus *status, REAL8Array **result,
		REAL8 A, REAL8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerDArray (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        REAL8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "DDotPowerDArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerD ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerD (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerD" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerDArray ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerDArray (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerDArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerSVector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, REAL4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerSVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotPowerSVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void DVectorDotPowerS ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, REAL4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerS (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerS" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DVectorDotPowerSVector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *B, REAL4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerSVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*B,
        REAL4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerSVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerSArray ( LALStatus *status, REAL8Array **result,
		REAL8 A, REAL4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerSArray (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "DDotPowerSArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerS ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerS (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerS" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerSArray ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerSArray (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerSArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, INT2Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void DVectorDotPowerI2 ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI2 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DVectorDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *B, INT2Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*B,
        INT2Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		REAL8 A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI2Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "DDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI2 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI2 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, INT4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void DVectorDotPowerI4 ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI4 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DVectorDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *B, INT4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*B,
        INT4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		REAL8 A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI4Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "DDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI4 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI4 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI4Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, INT8Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void DVectorDotPowerI8 ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI8 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DVectorDotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *B, INT8Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DVectorDotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*B,
        INT8Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DDotPowerI8Array ( LALStatus *status, REAL8Array **result,
		REAL8 A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DDotPowerI8Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "DDotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI8 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI8 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void DArrayDotPowerI8Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void DArrayDotPowerI8Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerSVector ( LALStatus *status, REAL8Vector **result,
		REAL4 A, REAL4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerSVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4			A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotPowerSVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void SVectorDotPowerS ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *A, REAL4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerS (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL4Vector		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerS" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SVectorDotPowerSVector ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *B, REAL4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerSVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4Vector		*B,
        REAL4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerSVector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerSArray ( LALStatus *status, REAL8Array **result,
		REAL4 A, REAL4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerSArray (
        LALStatus               *status,
        REAL8Array		**result,
        REAL4			A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "SDotPowerSArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerS ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, REAL4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerS (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerS" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerSArray ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, REAL4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerSArray (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerSArray" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		REAL4 A, INT2Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void SVectorDotPowerI2 ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI2 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL4Vector		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SVectorDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *B, INT2Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4Vector		*B,
        INT2Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		REAL4 A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI2Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL4			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "SDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI2 ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI2 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		REAL4 A, INT4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void SVectorDotPowerI4 ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI4 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL4Vector		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SVectorDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *B, INT4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4Vector		*B,
        INT4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		REAL4 A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI4Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL4			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "SDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI4 ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI4 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI4Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		REAL4 A, INT8Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void SVectorDotPowerI8 ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI8 (
        LALStatus               *status,
        REAL8Vector		**result,
        REAL4Vector		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SVectorDotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		REAL4Vector *B, INT8Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SVectorDotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL4Vector		*B,
        INT8Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SDotPowerI8Array ( LALStatus *status, REAL8Array **result,
		REAL4 A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SDotPowerI8Array (
        LALStatus               *status,
        REAL8Array		**result,
        REAL4			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "SDotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI8 ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI8 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void SArrayDotPowerI8Array ( LALStatus *status, REAL8Array **result,
		REAL4Array *A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void SArrayDotPowerI8Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL4Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I2DotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT2 A, INT2Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2DotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT2			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2DotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT2Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I2VectorDotPowerI2 ( LALStatus *status, REAL8Vector **result,
		INT2Vector *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2VectorDotPowerI2 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT2Vector		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2VectorDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT2Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I2VectorDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT2Vector *B, INT2Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2VectorDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT2Vector		*B,
        INT2Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2VectorDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT2Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I2DotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT2 A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2DotPowerI2Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT2			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I2DotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I2ArrayDotPowerI2 ( LALStatus *status, REAL8Array **result,
		INT2Array *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2ArrayDotPowerI2 (
        LALStatus		*status,
        REAL8Array		**result,
        INT2Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I2ArrayDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT2Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT2Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I2ArrayDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT2Array *A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I2ArrayDotPowerI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT2Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I2ArrayDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4DotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT4 A, INT2Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4DotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT4			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4DotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I4VectorDotPowerI2 ( LALStatus *status, REAL8Vector **result,
		INT4Vector *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4VectorDotPowerI2 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT4Vector		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4VectorDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT4Vector *B, INT2Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4VectorDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT4Vector		*B,
        INT2Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4DotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT4 A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4DotPowerI2Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT4			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I4DotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4ArrayDotPowerI2 ( LALStatus *status, REAL8Array **result,
		INT4Array *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4ArrayDotPowerI2 (
        LALStatus		*status,
        REAL8Array		**result,
        INT4Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4ArrayDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT4Array *A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4ArrayDotPowerI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT4Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4DotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		INT4 A, INT4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4DotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT4			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4DotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I4VectorDotPowerI4 ( LALStatus *status, REAL8Vector **result,
		INT4Vector *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4VectorDotPowerI4 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT4Vector		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4VectorDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		INT4Vector *B, INT4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4VectorDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT4Vector		*B,
        INT4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4DotPowerI4Array ( LALStatus *status, REAL8Array **result,
		INT4 A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4DotPowerI4Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT4			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I4DotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4ArrayDotPowerI4 ( LALStatus *status, REAL8Array **result,
		INT4Array *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4ArrayDotPowerI4 (
        LALStatus		*status,
        REAL8Array		**result,
        INT4Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I4ArrayDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		INT4Array *A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I4ArrayDotPowerI4Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT4Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}




























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT8 A, INT2Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I8VectorDotPowerI2 ( LALStatus *status, REAL8Vector **result,
		INT8Vector *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI2 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT8Vector		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8VectorDotPowerI2Vector ( LALStatus *status, REAL8Vector **result,
		INT8Vector *B, INT2Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8Vector		*B,
        INT2Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI2Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT8 A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI2Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT8			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I8DotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI2 ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT2 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI2 (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI2" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI2Array ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT2Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI2Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		INT8 A, INT4Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I8VectorDotPowerI4 ( LALStatus *status, REAL8Vector **result,
		INT8Vector *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI4 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT8Vector		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8VectorDotPowerI4Vector ( LALStatus *status, REAL8Vector **result,
		INT8Vector *B, INT4Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8Vector		*B,
        INT4Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI4Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI4Array ( LALStatus *status, REAL8Array **result,
		INT8 A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI4Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT8			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I8DotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI4 ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT4 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI4 (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI4" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI4Array ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT4Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI4Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI4Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		INT8 A, INT8Vector *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( B->data[iterator], A );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC"> 
\begin{verbatim}void I8VectorDotPowerI8 ( LALStatus *status, REAL8Vector **result,
		INT8Vector *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI8 (
        LALStatus               *status,
        REAL8Vector		**result,
        INT8Vector		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8VectorDotPowerI8Vector ( LALStatus *status, REAL8Vector **result,
		INT8Vector *B, INT8Vector *A )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8VectorDotPowerI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        INT8Vector		*B,
        INT8Vector		*A
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotPowerI8Vector" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = pow( A->data[iterator], B->data[iterator] );
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8DotPowerI8Array ( LALStatus *status, REAL8Array **result,
		INT8 A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8DotPowerI8Array (
        LALStatus               *status,
        REAL8Array		**result,
        INT8			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "I8DotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A, B->data[index] );
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI8 ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT8 B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI8 (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI8" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( A->data[index], B );
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixPowerC">
\begin{verbatim}void I8ArrayDotPowerI8Array ( LALStatus *status, REAL8Array **result,
		INT8Array *A, INT8Array *B )\end{verbatim}
 ************************************************** </lalLaTeX> */

void I8ArrayDotPowerI8Array (
        LALStatus		*status,
        REAL8Array		**result,
        INT8Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotPowerI8Array" , MATLABMATRIXPOWC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
	ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);


        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = pow( (A->data[index]) , (B->data[index]));
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}



