/********************************** <lalVerbatim file="StochasticDataHV">
Author: Anderson, W.G., Romano, J.D., and Whelan, J.T.
$Id: StochasticData.h,v 1.15 2002/06/08 20:56:20 whelan Exp $
**************************************************** </lalVerbatim> */

/******************************* <lalLaTeX file="StochasticDataH">
\section{Header \texttt{StochasticData.h}}
\label{s:StochasticData.h}

Provides structures needed for \texttt{StochasticSearchParams},
notably including \texttt{StochasticInitParams},
\texttt{StochasticDataSegment}, and
\texttt{StochasticDataSegmentVector}.


\subsection*{Synopsis}
\begin{verbatim}
#include "StochasticData.h"
\end{verbatim}

\subsection*{Error conditions}
\input{StochasticDataHErrTab}

\subsection*{Structures and Unions}

*************************************************** </lalLaTeX> */

#ifndef _STOCHASTICDATA_H
#define _STOCHASTICDATA_H

#include <lal/LALStdlib.h>
#include <lal/LALDatatypes.h>
#include <lal/LALRCSID.h>
#include <lal/Window.h>

#ifdef  __cplusplus   /* C++ protection. */
extern "C" {
#endif

NRCSID (STOCHASTICDATAH, "$Id: StochasticData.h,v 1.15 2002/06/08 20:56:20 whelan Exp $");

/******** <lalErrTable file="StochasticDataHErrTab"> ********/
#define STOCHASTICDATAH_ENNUL       1 
#define STOCHASTICDATAH_ENULL       2
#define STOCHASTICDATAH_ENSEG       3
#define STOCHASTICDATAH_ENPTS       4
#define STOCHASTICDATAH_ENFRQ       5
#define STOCHASTICDATAH_EALOC       6
#define STOCHASTICDATAH_ESTID       7

#define STOCHASTICDATAH_MSGENNUL    "Non-null pointer"
#define STOCHASTICDATAH_MSGENULL    "Null pointer"
#define STOCHASTICDATAH_MSGENSEG    "Number of data segments is zero or negative"
#define STOCHASTICDATAH_MSGENPTS    "Number of points in a data segment is zero or negative"
#define STOCHASTICDATAH_MSGENFRQ    "Number of frequencies is zero or negative"
#define STOCHASTICDATAH_MSGEALOC    "Memory allocation error"   
#define STOCHASTICDATAH_MSGESTID    "Detector Site ID out of range"
/******** </lalErrTable> ********/

/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Structure \texttt{StochasticInitParams}}
\index{\texttt{StochasticInitParams}}

\noindent
The fields are:
\begin{description}
\item[\texttt{UINT4 numSegments}] Number of data segments
\item[\texttt{UINT4 numPoints}] Number of points in a data segment
\item[\texttt{REAL8 baseFreq}] Hetrodyning base frequency of time series data
\item[\texttt{WindowType windowType1}] Type of window to be used on first data stream
\item[\texttt{UINT4 windowTop1}] Width of flat top for first window
\item[\texttt{WindowType windowType2}] Type of window to be used on second data stream
\item[\texttt{UINT4 windowTop2}] Width of flat top for second window
\item[\texttt{UINT4 fullLength}] Length after zero-padding
\item[\texttt{UINT4 numFrequencies}] Number of frequencies in optimal filter
\item[\texttt{REAL8 f0}] Start frequency for optimal filter
\item[\texttt{REAL8 deltaF}] Frequency spacing for optimal filter
\item[\texttt{UINT4 outputNumFreq}] Number of frequencies in cross-correlation spectrum
\item[\texttt{REAL8 outputF0}] Start frequency for CC spectrum
\item[\texttt{REAL8 outputDeltaF}] Frequency spacing for CC spectrum
\item[\texttt{BOOLEAN epochsMatch}] Check that time streams are simultaneous
\item[\texttt{CHAR siteID1}] Identifier for first detector
\item[\texttt{CHAR siteID2}] Identifier for second detector
\item[\texttt{REAL4 *azimuth1}] Azimuth of first detector in degrees East of North (null if not applicable)
\item[\texttt{REAL4 *azimuth2}] Azimuth of second detector in degrees East of North (null if not applicable)
\item[\texttt{UINT4 outputType}] Bitmask for DSO outputs
\end{description}

*************************************************** </lalLaTeX> */

typedef struct
tagStochasticInitParams
{
  UINT4                           numSegments;
  UINT4                           numPoints;
  REAL8				  baseFreq;
  WindowType                      windowType1;
  UINT4                           windowTop1;
  WindowType                      windowType2;
  UINT4                           windowTop2;
  UINT4                           fullLength;
  UINT4                           numFrequencies;
  REAL8                           f0;
  REAL8                           deltaF;
  UINT4                           outputNumFreq;
  REAL8                           outputF0;
  REAL8                           outputDeltaF;
  BOOLEAN                         epochsMatch;
  CHAR                            siteID1;
  CHAR                            siteID2;
  REAL4                          *azimuth1;
  REAL4                          *azimuth2;
  UINT4                           outputType;
}
StochasticInitParams;

/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Structure \texttt{StochasticRealDataSegment}}
\index{\texttt{StochasticRealDataSegment}}

\noindent
The fields are:
\begin{description}
\item[\texttt{REAL4TimeSeries *data1}]
\item[\texttt{REAL4TimeSeries *data2}]
\end{description}

*************************************************** </lalLaTeX> */

typedef struct
tagStochasticRealDataSegment
{
    REAL4TimeSeries*                data1;
    REAL4TimeSeries*                data2;
}
StochasticRealDataSegment;

/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Structure \texttt{StochasticComplexDataSegment}}
\index{\texttt{StochasticComplexDataSegment}}

\noindent
The fields are:
\begin{description}
\item[\texttt{COMPLEX8TimeSeries *data1}]
\item[\texttt{COMPLEX8TimeSeries *data2}]
\end{description}

*************************************************** </lalLaTeX> */

typedef struct
tagStochasticComplexDataSegment
{
    COMPLEX8TimeSeries*                data1;
    COMPLEX8TimeSeries*                data2;
}
StochasticComplexDataSegment;

/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Structure \texttt{StochasticRealDataSegmentVector}}
\index{\texttt{StochasticRealDataSegmentVector}}

\noindent
The fields are:
\begin{description}
\item[\texttt{UINT4 length}]
\item[\texttt{StochasticRealDataSegment *data}]
\end{description}

*************************************************** </lalLaTeX> */

typedef struct
tagStochasticRealDataSegmentVector
{
    UINT4                           length;
    StochasticRealDataSegment*          data;
}
StochasticRealDataSegmentVector;

/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Structure \texttt{StochasticComplexDataSegmentVector}}
\index{\texttt{StochasticComplexDataSegmentVector}}

\noindent
The fields are:
\begin{description}
\item[\texttt{UINT4 length}]
\item[\texttt{StochasticComplexDataSegment *data}]
\end{description}

*************************************************** </lalLaTeX> */

typedef struct
tagStochasticComplexDataSegmentVector
{
    UINT4                           length;
    StochasticComplexDataSegment*          data;
}
StochasticComplexDataSegmentVector;

void
LALSCreateStochasticDataSegmentVector (
    LALStatus*                      status,
    StochasticRealDataSegmentVector**   vector,
    StochasticInitParams*           params
);

void
LALSDestroyStochasticDataSegmentVector (
    LALStatus*                      status,
    StochasticRealDataSegmentVector**   vector
);

void
LALCCreateStochasticDataSegmentVector (
    LALStatus*                      status,
    StochasticComplexDataSegmentVector**   vector,
    StochasticInitParams*           params
);

void
LALCDestroyStochasticDataSegmentVector (
    LALStatus*                      status,
    StochasticComplexDataSegmentVector**   vector
);


/******************************* <lalLaTeX file="StochasticDataH">

\subsubsection*{Union \texttt{StochasticDataSegmentVector}}
\index{\texttt{StochasticComplexSegmentVector}}

\noindent
The fields are:
\begin{description}
\item[\texttt{StochasticRealDataSegmentVector *realVec}]
\item[\texttt{StochasticComplexDataSegmentVector *complexVec}]
\end{description}

*************************************************** </lalLaTeX> */

typedef union
tagStochasticDataSegmentVector
{
    StochasticRealDataSegmentVector    *realVec;
    StochasticComplexDataSegmentVector    *complexVec;
}
StochasticDataSegmentVector;

#ifdef  __cplusplus
}
#endif /* C++ protection. */

#endif /* _STOCHASTICDATA_H  */

/******************************* <lalLaTeX file="StochasticDataH">
  
\vfill{\footnotesize\input{StochasticDataHV}}

\newpage\input{StochasticDataC}

*************************************************** </lalLaTeX> */
