/********************************** <lalVerbatim file="TFCConditionDataCV">
Author: Julien Sylvestre
$Id: ConditionData.c,v 1.14 2002/04/16 19:04:35 julien Exp $
**************************************************** </lalVerbatim> */

#include <lal/LALStdlib.h>
#include <lal/TFClusters.h>
#include <lal/TFCThresholds.h>
#include <lal/AVFactories.h>
#include <lal/Random.h>
#include <ConditionData.h>
#include <InitSearch.h>
#include <strings.h>



NRCSID( CONDITIONDATAC , "power $Id: ConditionData.c,v 1.14 2002/04/16 19:04:35 julien Exp $" );

void
LALConditionData(
    LALStatus             *status,
    LALSearchInput        *inout,
    void                  *searchParams,
    LALMPIParams          *mpiParams
                )
{
  TFCSearchParams *params;

  INITSTATUS (status, "LALConditionData", CONDITIONDATAC);
  ATTATCHSTATUSPTR (status);

  params = (TFCSearchParams *) searchParams;

  /*
   *
   * condition the data on nodes and searchMaster
   *
   */

  ASSERT (searchParams, status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL);

  ASSERT ( inout->numberSequences >= 1, status, CONDITIONDATAH_EINPUT, CONDITIONDATAH_MSGEINPUT); 



  {
    RealFFTPlan *plan = NULL;
    UINT4 i, j, nPts, nTSteps, si, ninjsig = 0;
    COMPLEX8Vector *fTr = NULL;
    REAL4Vector iVec;
    

    char haveSpec = 0;
    REAL4 *dmro = NULL, *resp = NULL, *spec = NULL, *rho = NULL;

    REAL4 **injsig = NULL;
    UINT4 *injsigSize = NULL;
    INT4 *injsigOffset = NULL;

    COMPLEX8  *resptmp = NULL;
    RiceThresholdParams rtp;

    UINT4 minf,siz2,sizz;

    /*
    if(params->dir->minf * params->T - floor(params->dir->minf * params->T) < 0.5)
      minf = (UINT4)floor(params->dir->minf * params->T);
    else minf = (UINT4)ceil(params->dir->minf * params->T);
    */

    minf = 1; /* because spectrogram built from 1/T */

    siz2 =  1 + (UINT4)ceil(0.5*params->T*(double)params->fs);
    sizz = siz2 - minf;


    spec = (REAL4 *)LALMalloc(sizz * sizeof(REAL4));    
    if(!spec) {
      ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
    }


    /*
     *
     * multiDim data expected to contain Data
     * but may also contain Spectrum or Response
     *
     */

    for(si=0;si<inout->numberSequences;si++) {

      /* Injected signal */
      if(strstr(inout->sequences[si].name, INPUTNAME_INJECTED)) {
	
	UINT4 ind = ninjsig;

	ninjsig++;

	injsig = (REAL4 **)LALRealloc(injsig, ninjsig * sizeof(REAL4 *));
	if(!injsig) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}
	injsigSize = (UINT4 *)LALRealloc(injsigSize, ninjsig * sizeof(UINT4));
	if(!injsigSize) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}
	injsigOffset = (INT4 *)LALRealloc(injsigOffset, ninjsig * sizeof(INT4));
	if(!injsigOffset) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}

	injsigSize[ind] = inout->sequences[si].dimensions[0];
	if(injsigSize[ind] < 2) {
	  ABORT ( status, CONDITIONDATAH_EISIG, CONDITIONDATAH_MSGEISIG );
	}

	injsig[ind] = (REAL4 *)LALMalloc((injsigSize[ind] - 1) * sizeof(REAL4));
	if(!injsig[ind]) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}

	/* cast */
	switch(inout->sequences[si].type) {

	case real_4:
	  injsigOffset[ind] = (INT4)inout->sequences[si].data.real4[0];
	  memcpy(injsig[ind],inout->sequences[si].data.real4+1,(injsigSize[ind]-1)*sizeof(REAL4));
	  break;

#define TFCCAST(TYPE__,PTR__) \
    case TYPE__ : \
      injsigOffset[ind] = (INT4)inout->sequences[si].data.PTR__[0];\
      for(i=1; i<injsigSize[ind]; i++) \
	injsig[ind][i-1] = (REAL4)inout->sequences[si].data.PTR__[i]; \
      break

	  TFCCAST(boolean_lu,boolean);
	  TFCCAST(char_s,chars);
	  TFCCAST(char_u,charu);
	  TFCCAST(int_2s,int2s);
	  TFCCAST(int_2u,int2u);
	  TFCCAST(int_4s,int4s);
	  TFCCAST(int_4u,int4u);
	  TFCCAST(int_8s,int8s);
	  TFCCAST(int_8u,int8u);
	  TFCCAST(real_8,real8);

#undef TFCCAST

	default:
	  ABORT ( status, CONDITIONDATAH_EISIG, CONDITIONDATAH_MSGEISIG );
	}


      }

      /* main data */
      else if(strstr(inout->sequences[si].name, INPUTNAME_CHANNEL)) {

	dmro = (REAL4 *)LALMalloc(params->NData * sizeof(REAL4));    
	if(!dmro) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}

	ASSERT ( inout->sequences[si].dimensions, status, CONDITIONDATAH_EZERO, CONDITIONDATAH_MSGEZERO);

	/* check size */
	if(inout->sequences[si].dimensions[0] != params->NData) {
	  ABORT (status, CONDITIONDATAH_ENDAT, CONDITIONDATAH_MSGENDAT);
	}

	/* cast */
	switch(inout->sequences[si].type) {

	case real_4:
	  memcpy(dmro,inout->sequences[si].data.real4,params->NData*sizeof(REAL4));
	  break;

#define TFCCAST(TYPE__,PTR__) \
    case TYPE__ : \
      for(i=0; i<params->NData; i++) \
	dmro[i] = (REAL4)inout->sequences[si].data.PTR__[i]; \
      break

	  TFCCAST(boolean_lu,boolean);
	  TFCCAST(char_s,chars);
	  TFCCAST(char_u,charu);
	  TFCCAST(int_2s,int2s);
	  TFCCAST(int_2u,int2u);
	  TFCCAST(int_4s,int4s);
	  TFCCAST(int_4u,int4u);
	  TFCCAST(int_8s,int8s);
	  TFCCAST(int_8u,int8u);
	  TFCCAST(real_8,real8);

#undef TFCCAST

	default:
	  ABORT ( status, CONDITIONDATAH_EDTYP, CONDITIONDATAH_MSGEDTYP );
	}

	/* get time info */
	params->tseries->epoch.gpsSeconds = inout->sequences[si].range.dTime.startSec;
	params->tseries->epoch.gpsNanoSeconds = inout->sequences[si].range.dTime.startNan;
      }

      else if(strstr(inout->sequences[si].name, INPUTNAME_SPECTRUM)) {

	haveSpec = 1;

	/* check size */
	if(inout->sequences[si].dimensions[0] != siz2) {
	  ABORT (status, CONDITIONDATAH_ENDAT, CONDITIONDATAH_MSGENDAT);
	}

	/* cast */
	switch(inout->sequences[si].type) {

#define TFCCAST(TYPE__,PTR__) \
    case TYPE__ : \
      for(i=minf; i<siz2; i++) \
	spec[i - minf] = (REAL4)inout->sequences[si].data.PTR__[i]; \
      break

	  TFCCAST(real_4,real4);
	  TFCCAST(boolean_lu,boolean);
	  TFCCAST(char_s,chars);
	  TFCCAST(char_u,charu);
	  TFCCAST(int_2s,int2s);
	  TFCCAST(int_2u,int2u);
	  TFCCAST(int_4s,int4s);
	  TFCCAST(int_4u,int4u);
	  TFCCAST(int_8s,int8s);
	  TFCCAST(int_8u,int8u);
	  TFCCAST(real_8,real8);

#undef TFCCAST

	default:
	  ABORT ( status, CONDITIONDATAH_EDTYP, CONDITIONDATAH_MSGEDTYP );
	}

      }

      else if(strstr(inout->sequences[si].name, INPUTNAME_RESPONSE) &&
	      params->searchMaster) {

	/* check size */
	if(inout->sequences[si].dimensions[0] != siz2) {
	  ABORT (status, CONDITIONDATAH_ENDAT, CONDITIONDATAH_MSGENDAT);
	}

	resp = (REAL4 *)LALMalloc(sizz * sizeof(REAL4));    
	if(!resp) {
	  ABORT ( status, CONDITIONDATAH_EALOC, CONDITIONDATAH_MSGEALOC);
	}

	/* read */
	if(inout->sequences[si].type != complex_8) {
	  ABORT ( status, CONDITIONDATAH_EDTYP, CONDITIONDATAH_MSGEDTYP );
	}

	resptmp = inout->sequences[si].data.complex8;

	
	/* copy */
	for(i=minf;i<siz2;i++) 
	  resp[i - minf] = resptmp[i].re * resptmp[i].re + resptmp[i].im * resptmp[i].im;

	params->resp = resp;
      }

      else {
	ABORT ( status, CONDITIONDATAH_EINPUT, CONDITIONDATAH_MSGEINPUT );
      }
    }

      
    /* check we have data */
    if(!dmro) {
      ABORT ( status, CONDITIONDATAH_EDMRO, CONDITIONDATAH_MSGEDMRO );
    }
    
    if(haveSpec && params->eGoal == 0) { 
      UINT4 nFreq = 1 + (UINT4)ceil(0.5*params->T*(double)params->fs);
      REAL8 thr = -log(params->bpp) * 0.5 * (double)(params->fs);

      if(!nFreq || isnan(thr) || nFreq <= minf) {
	ABORT ( status, CONDITIONDATAH_ENUMZ, CONDITIONDATAH_MSGENUMZ );
      }

      nFreq -= minf;

      for(j=0;j<nFreq;j++) {
	params->dir->rho[j] = thr * spec[j];
      }


    }
    else {

      /* compute thresholds; redundant, done on every slave */
      if(params->eGoal > 0.0) {

	REAL4 norm, Pb, P2b, rad, Nsigma, nPb, nP2b, Pbuf;
	REAL4 *P;
	UINT4 k, nN;

	Nsigma = params->Nsigma;

	rtp.bpp = params->bpp;
	rtp.eGoal = params->eGoal;
	rtp.nFreq = (UINT4)ceil(0.5*params->T*(double)params->fs);

	if(!rtp.nFreq) {
	  ABORT ( status, CONDITIONDATAH_ENUMZ, CONDITIONDATAH_MSGENUMZ );
	}

	rtp.P0 = (REAL8 *)LALMalloc(rtp.nFreq * sizeof(REAL8));
	if(!rtp.P0) {ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL);} 
	rtp.Q = (REAL8 *)LALMalloc(rtp.nFreq * sizeof(REAL8));
	if(!rtp.Q) {ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL);} 
	
	bzero(rtp.P0, rtp.nFreq * sizeof(REAL8));
	bzero(rtp.Q, rtp.nFreq * sizeof(REAL8));

	nPts = params->T * (double)params->fs;
	nTSteps = (UINT4)floor((double)params->NData / (double)nPts);
      
	if(!nTSteps) {
	  ABORT ( status, CONDITIONDATAH_ENUMZ, CONDITIONDATAH_MSGENUMZ );
	}
    
	iVec.length = nPts;
      
	if(!nPts) {
	  ABORT ( status, CONDITIONDATAH_ENUMZ, CONDITIONDATAH_MSGENUMZ );
	}

	P = (REAL4 *)LALMalloc(sizeof(REAL4) * nTSteps * nPts/2);
	if(!P) {ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL);} 

	/* old function
	   LALEstimateForwardRealFFTPlan(status->statusPtr, &plan, nPts);
	*/

	LALCreateForwardRealFFTPlan(status->statusPtr, &plan, nPts, 0);
	CHECKSTATUSPTR (status);
      
	LALCCreateVector(status->statusPtr, &fTr, nPts/2 + 1);
	CHECKSTATUSPTR (status);

	norm = sqrt((REAL4)nPts);

	for(i=0;i<nTSteps;i++) {
	  iVec.data = dmro + i * nPts;
	  LALForwardRealFFT(status->statusPtr, fTr, &iVec, plan);

	  for(j=1; j<nPts/2+1; j++) {
	    /* note: error in RiceThreshold is absolute, not relative */
	    fTr->data[j].re /= norm;
	    fTr->data[j].im /= norm;

	    P[(j-1)*nTSteps+i] = Pbuf = fTr->data[j].re*fTr->data[j].re + fTr->data[j].im*fTr->data[j].im;
	    /* NOTE: rho will be computed from 1/T to Nyquist, i.e. not for DC */
	    rtp.P0[j-1] += Pbuf;
	    rtp.Q[j-1] += Pbuf * Pbuf;

	  }
	}

	for(j=0; j<nPts/2; j++) {
	  Pb = rtp.P0[j] / (REAL4)nTSteps;
	  P2b = rtp.Q[j] / (REAL4)nTSteps;

	  if(j>=minf) {
	    spec[j - minf] = Pb;
	  }

	  rad = 2.0 * Pb * Pb - P2b;

	  if(rad<0.0) {
	    /*	    ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL); */
	    rad = 0.0;
	  }

	  rad = sqrt(rad);
	  rtp.P0[j] = Pb - rad;
	  rtp.Q[j] = rad;
	}
	
	/* rerun, computing mean & variance without last NSigma */
	for(j=0; j<nPts/2; j++) {
	  nPb = nP2b = 0;
	  nN = 0;

	  for(k=0;k < nTSteps; k++) {
	    if(P[j*nTSteps+k] < rtp.Q[j] + Nsigma * rtp.P0[j]) {
	      nPb += P[j*nTSteps+k];
	      nP2b += P[j*nTSteps+k]*P[j*nTSteps+k];
	      nN++;
	    }
	  }

	  Pb = nPb / (REAL4)nN;
	  P2b = nP2b / (REAL4)nN;

	  if(j>=minf) {
	    spec[j - minf] = Pb;
	  }

	  rad = 2.0 * Pb * Pb - P2b;

	  if(rad<0.0) {
	    /*	    ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL); */
	    rad = 0.0;
	  }

	  rad = sqrt(rad);
	  rtp.P0[j] = Pb - rad;
	  rtp.Q[j] = rad;

	}

	rho = (REAL4 *)LALMalloc(rtp.nFreq * sizeof(REAL4));
	if(!rho) {ABORT ( status, CONDITIONDATAH_ENULL, CONDITIONDATAH_MSGENULL);}
	
	LALTFCRiceThreshold(status->statusPtr, rho, &rtp);
	CHECKSTATUSPTR (status);

	/* note: params->dir->rho = 1E30 in InitSearch */
	/*
	if(minf) {
	  for(j=minf;j<rtp.nFreq;j++) {
	    params->dir->rho[j - minf] = (REAL8)rho[j-1];
	  }
	}
	else {
	  for(j=0;j<nPts/2;j++) {
	    params->dir->rho[j+1] = (REAL8)rho[j];
	  }
	}
	*/

	for(j=0;j<nPts/2;j++) {
	  params->dir->rho[j] = (REAL8)rho[j];
	}


	/* clean up */

	LALCDestroyVector(status->statusPtr, &fTr);
	CHECKSTATUSPTR (status);

	LALDestroyRealFFTPlan(status->statusPtr, &plan);
	CHECKSTATUSPTR (status);

	LALFree(rho);

	LALFree(rtp.P0);
	LALFree(rtp.Q);

	LALFree(P);
      }
      else { /* no need to compute threshold: white noise */

	UINT4 nFreq = 1 + (UINT4)ceil(0.5*params->T * (double)params->fs) - minf;
	REAL8 thr = -log(params->bpp);

	if(!nFreq || isnan(thr)) {
	  ABORT ( status, CONDITIONDATAH_ENUMZ, CONDITIONDATAH_MSGENUMZ );
	}


	for(j=0;j<nFreq;j++) {
	  params->dir->rho[j] = thr;
	  spec[j] = 1.0;
	}

      }
    }


    params->dir->freqBins = 1 + (UINT4)ceil(0.5*params->T * (double)params->fs) - minf;

    params->dmro = dmro;    
    params->resp = resp;
    params->spec = spec;

    /* if there is an injected signal input, add to dmro */
    for(i=0; i<ninjsig; i++) {

      /* NOTE: injsigSize is 1+data size !!! */

      if(injsigOffset[i] < 0) {
	/* generate random offset */
	RandomParams *rparams;
	INT4 seed = 0;
	UINT4 ub = params->NData - injsigSize[i] + 1; /* supremum */
	REAL4 dev;
	LALCreateRandomParams(status->statusPtr, &rparams, seed);
	CHECKSTATUSPTR (status);
	LALUniformDeviate(status->statusPtr, &dev, rparams);
	CHECKSTATUSPTR (status);
	injsigOffset[i] = (INT4)floor(dev * (REAL4)ub);
	LALDestroyRandomParams(status->statusPtr, &rparams);
	CHECKSTATUSPTR (status);
      }

      if(injsigSize[i] + injsigOffset[i] > 1 + params->NData) {
	ABORT ( status, CONDITIONDATAH_EISIGO, CONDITIONDATAH_MSGEISIGO );
      }

      for(j=0; j+1<injsigSize[i]; ++j) {
	(params->dmro[j + injsigOffset[i]]) += injsig[i][j];
      }

      /* clean up */
      LALFree(injsig[i]);

    }

    if(injsig) {
      LALFree(injsig);
      LALFree(injsigOffset);
      LALFree(injsigSize);
    }

  } /* else of if(searchMaster) */



  DETATCHSTATUSPTR (status);
  RETURN (status);
}

